Mainly for my own use.
They are libs I frequently use and have (mostly) written myself
Also some requirements for packages I frequently use
Rights to required packages depend on their respective authors!